# coding: utf8
from __future__ import unicode_literals

_exc = {
    "Rp": "$",
    "IDR": "$",
    "RMB": "$",
    "USD": "$",
    "AUD": "$",
    "GBP": "$",
}

NORM_EXCEPTIONS = {}

for string, norm in _exc.items():
    NORM_EXCEPTIONS[string] = norm
    NORM_EXCEPTIONS[string.title()] = norm
